@@ -19,7 +19,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "../authenticator.h"
 // Qt
-#include <QtTest/QtTest>
+#include <QtTest>
 
 class AuthenticatorTest : public QObject
 {
